/*------------------------------------------------
--                 LAZZE-GETOBZ                 --
--------------------------------------------------
-- Filename      : game.h
-- Description   : Misc game stuff
--                 
--
-- Author        : Lars Englund
--                 d99las@dtek.chalmers.se
--
--                 Tobias Gedell
--                 d99getob@dtek.chalmers.se
--
-- Created       : 020831
-- Last update   : 020902
------------------------------------------------*/

#ifndef GAME_H
#define GAME_H

#define UP              1
#define DOWN            2
#define LEFT            3
#define RIGHT           4

#define PLAIN           '.'
#define BASE            '@'
#define WALL            '#'
#define WATER           '~'

#define PACKET          ((char)1)
#define DEST            ((char)2)

#define MAX_GAME_PACKETS    10000

typedef struct _packetStruct
{
    int id;
    int weight;
    int destX;
    int destY;
    int x,y;
    int score;
    int timeStamp;
    struct _packetStruct *next;
    struct _packetStruct *prev;
} packetStruct;


typedef struct _playerStruct
{
    int id;
    int x;
    int y;
    int numPackets;
    int timeStamp;
    packetStruct *packets[MAX_GAME_PACKETS];     // Packet indices
    struct _playerStruct *next;
    struct _playerStruct *prev;
} playerStruct;


void timeStampPlayer( int playId );
void addPlayer( int x, int y, int id );
void movePlayer( int id, int dir );
void removeDeadPlayers();
void removePacket(int packId);
void playerPick(int playId, int packId);
void playerDrop(int playId, int packId);
packetStruct *addPacket(int id, int destX, int destY, int weight);


extern int numGamePackets;
extern packetStruct *pfirstGamePacket;

extern int numPlayers;
extern playerStruct *pfirstPlayer;
extern playerStruct *probot;

extern int robotNumPackets;
extern packetStruct **robotPackets;

extern int moveCount;

#endif
